Toolbar Configurator

# Toolbar Configurator Help

Select configurator type Basic Advanced

## What Am I Doing Here?

Arrange toolbar groups, toggle button visibility according to your needs and get your toolbar configuration.

You can replace the content of the `config.js` file with the generated configuration. If you already set some configuration options you will need to merge both configurations.

Read more about different ways of setting configuration and do not forget about clearing browser cache.

Arranging toolbar groups is the recommended way of configuring the toolbar, but if you need more freedom you can use the advanced configurator.

With this code editor you can edit your toolbar configuration live.

You can replace the content of the `config.js` file with the generated configuration. If you already set some configuration options you will need to merge both configurations.

Read more about different ways of setting configuration and do not forget about clearing browser cache.